<?php

/*
Plugin Name: GetSimple News Manager
Description: A basic news manager
Version: 1.2.5 Mod 0.4
Author: Rogier Koppejan
Author URI: http://rxgr.nl/getsimple/
Mod Author: Alessio_romaTM
Mod Author URI: http://www.lafucinadiharad.tk
*/

# get correct id for plugin
$thisfile = basename(__FILE__, '.php');

# register plugin
register_plugin(
  $thisfile,
  'News Manager',
  '1.2.5 Mod 0.4',
  'Rogier Koppejan',
  'http://rxgr.nl/getsimple/',
  'A basic news manager, Mod Version by Alessio_romaTM',
  'pages',
  'news_manager'
);


# hooks
add_action('pages-sidebar', 'createSideMenu', array($thisfile, 'News Manager'));

# definitions
define('ARTICLEDATA', GSDATAPATH  . 'articles/');


############################### ADMIN FUNCTIONS ################################


/*******************************************************
 * @function news_manager
 * @action main function, creates, edits or deletes articles
 */
function news_manager() {
  if (!is_writable(ARTICLEDATA)) {
    $path = realpath(ARTICLEDATA);
    echo '<h3>News Manager</h3><p>The directory "<i>$path</i>" does not exist,
    or is not writable. It is required for this plugin to function properly.
    Please create it manually and make sure it is writable.</p>';
  } elseif (isset($_GET['edit'])) {
    $id = empty($_GET['edit']) ? uniqid() : $_GET['edit'];
    edit_article($id);
  } elseif (isset($_GET['delete'])) {
    $id = $_GET['delete'];
    delete_article($id);
  } elseif (isset($_POST['submit'])) {
    save_article();
  } else {
    article_overview();
  }
}


/*******************************************************
 * @function article_overview
 * @action list articles and provide options for editing
 */
function article_overview() {
  $articles = get_articles();
  ?>
  <h3 class="floated">News Manager</h3>
  <div class="edit-nav clearfix">
    <a href="load.php?id=news_manager&edit">Create New Article</a>
  </div>
  <?php
  if (!empty($articles)) {
    echo '<table class="highlight">';
    foreach ($articles as $article) {
      $id = basename($article, ".xml");
      $file = ARTICLEDATA . $article;
      $data = @getXML($file);
      $date = $data->date;
      if (empty($data->title))
        $title = '[No Title]';
      else
        $title = cl($data->title);
      ?>
      <tr>
        <td>
          <a href="load.php?id=news_manager&edit=<?php echo $id; ?>" title="Edit article: <?php echo $title; ?>">
            <?php echo $title; ?>
          </a>
        </td>
        <td style="text-align: right;">
          <span><?php echo $date; ?></span>
        </td>
        <td class="delete">
          <a href="load.php?id=news_manager&delete=<?php echo $id; ?>" class="delconfirm" title="Delete article: <?php echo $title; ?>?">
            X
          </a>
        </td>
      </tr>
      <?php
    }
    echo '</table>';
  }
  echo '<p><b>' . count($articles) . '</b> articles</p>';
}


/*******************************************************
 * @function edit_article
 * @param $id - unique article id
 * @action edit or create new articles
 */
function edit_article($id) {
  $file = ARTICLEDATA . $id . '.xml';
  $data = @getXML($file);
  $title = @stripslashes($data->title);
  $content = @stripslashes($data->content);
  $excerpt = @stripslashes($data->excerpt);
  ?>
  <h3><?php if (empty($data)) echo 'Create New'; else echo 'Edit'; ?> Article</h3>
  <form class="largeform" action="load.php?id=news_manager" method="post" accept-charset="utf-8">
    <p>
      <input name="id" type="hidden" value="<?php echo $id; ?>" />
    <p>
      <input class="text title" name="post-title" type="text" value="<?php echo $title; ?>" />
    </p>
    <p>
      <textarea name="post-content"><?php echo $content; ?></textarea>
    </p>
    <p>
      <b>Excerpt:</b><br />
      <textarea name="post-excerpt" style="height: 50px"><?php echo $excerpt; ?></textarea>
      <span style="color: #999;">
        Excerpts are <i>optional</i> hand-crafted summaries of your article content.
      </span>
    </p>
    <p>
      <input name="submit" type="submit" class="submit" value="Save Article" />
      &nbsp;&nbsp;or&nbsp;&nbsp;
      <a href="load.php?id=news_manager" class="cancel" title="Cancel">Cancel</a>
    </p>
  </form>
  <?php
  // Include ckeditor
  global $HTMLEDITOR;
  if (isset($_GET['id']) and $_GET['id'] == "news_manager") {
    if (isset($HTMLEDITOR) && $HTMLEDITOR != '') {
      $TOOLBAR = "['Bold', 'Italic', 'Underline', 'NumberedList', 'BulletedList', 'JustifyLeft', 'JustifyCenter', 'JustifyRight', 'JustifyBlock', 'Link', 'Unlink', 'Image', 'RemoveFormat', 'Source']";
      $EDLANG = defined('GSEDITORLANG') ? GSEDITORLANG : 'en';
      ?>
      <script type="text/javascript" src="template/js/ckeditor/ckeditor.js"></script>
      <script type="text/javascript">
        var editor = CKEDITOR.replace( 'post-content', {
          skin : 'getsimple',
          forcePasteAsPlainText : true,
          language : '<?php echo $EDLANG; ?>',
          defaultLanguage : '<?php echo $EDLANG; ?>',
          entities : true,
          uiColor : '#FFFFFF',
          height: '300',
          toolbar :
          [
          <?php echo $TOOLBAR; ?>
          ]
        });
      </script>
      <?php
    }
  }
}


/*******************************************************
 * @function save_article
 * @action write $_POST data to a file
 */
function save_article() {
  $id = $_POST['id'];
  $file = ARTICLEDATA . $id . '.xml';
  $title = safe_slash_html($_POST['post-title']);
  $content = safe_slash_html($_POST['post-content']);
  $excerpt = safe_slash_html($_POST['post-excerpt']);

  if (!file_exists($file)) {
    $date = date('j M Y');
  } else {
    $data = @getXML($file);
    $date = $data->date;
  }

  $xml = new SimpleXMLExtended('<?xml version="1.0" encoding="UTF-8"?><item></item>');
  $obj = $xml->addChild('title');
  $obj->addCData($title);
  $obj = $xml->addChild('date');
  $obj->addCData($date);
  $obj = $xml->addChild('content');
  $obj->addCData($content);
  $obj = $xml->addChild('excerpt');
  $obj->addCData($excerpt);
  XMLsave($xml, $file);

  if (!is_writable($file))
    echo '<div class="error">Unable to write article data to file</div>';
  else
    echo '<div class="updated">The article has been succesfully saved</div>';

  article_overview();
}


/*******************************************************
 * @function delete_article
 * @param $id - unique article id
 * @action deletes the requested article
 */
function delete_article($id) {
  $file = ARTICLEDATA . $id . '.xml';
  if (file_exists($file))
    unlink($file);
  if (file_exists($file))
    echo '<div class="error">Unable to delete the article</div>';
  else
    echo '<div class="updated">The article has been deleted</div>';
  article_overview();
}


############################### SITE FUNCTIONS #################################


/*******************************************************
 * @function show_articles
 * @param $n - number of articles per page
 * @action displays news articles on theme/site page
 */
function show_articles($n = NULL) {
  if (isset($_GET['article'])) {
    $id = $_GET['article'];
    show_article($id);
  } else {
    $articles = get_articles();
    if (!empty($articles)) {
      if (isset($n) && $n > 0) {
        $index = isset($_GET['page']) ? $_GET['page'] : 0;
        $pages = array_chunk($articles, $n);
        if (is_numeric($index) && $index >= 0 && $index < sizeof($pages))
          $articles = $pages[$index];
        else
          $articles = array();
      }
      foreach ($articles as $article) {
        $id = basename($article, '.xml');
        show_article($id, TRUE);
      }
      if (!empty($articles) && isset($pages) && sizeof($pages) > 1)
        show_navigation($index, sizeof($pages));
    }
  }
}


/*******************************************************
 * @function show_article
 * param $id - unique article id
 * param $excerpt - if TRUE, print only a short article summary
 * @action prints the article with given id on theme/site page
 */
function show_article($id, $excerpt=FALSE) {
  require_once GSPLUGINPATH."ARGuestbook.php";
  $file = ARTICLEDATA . $id . '.xml';
  $data = getXML($file);
  if (!empty($data)) {
    $date = $data->date;
    $title = stripslashes(htmlspecialchars_decode($data->title, ENT_QUOTES));
    $content = stripslashes(htmlspecialchars_decode($data->content, ENT_QUOTES));
    if ($excerpt && !empty($data->excerpt)) {
      $content = '<p>' . stripslashes(htmlspecialchars_decode($data->excerpt, ENT_QUOTES)) . '</p>';
    }
    $url = get_page_url(TRUE);
    $url .= preg_match('/\?/', $url) ? '&' : '?';
    $url .= "article=$id";
	$valore = guestbook_check(&$content,&$excerpt);
    ?>
    <div class="article">
      <h3 class="article_title">
        <a href="<?php echo $url; ?>"><?php echo $title; ?></a>
      </h3>
      <p class="article_date">Posted on: <?php echo $date; ?></p>
      <div class="article_content"><?php echo $content; ?></div>
      <?php
	  if($valore == true) showGuestbook(&$id,&$title);
      if ($excerpt && !empty($data->excerpt))
        echo "<p class=\"article_link\"><a href=\"$url\">Read more</a></p>";
      elseif (!$excerpt)
        echo "<p class=\"article_meta\"><b>Permalink:</b> <a href=\"$url\">$url</a></p>";
      ?>
    </div>
    <?php
  } else {
    echo '<p>The requested article does not exist.</p>';
  }
}


/*******************************************************
 * @function show_navigation
 * param $index - current page index
 * param $n - total number of pages
 * @action provides links to navigate between article pages
 */
function show_navigation($index, $n) {
  $url = get_page_url(TRUE);
  $url .= preg_match('/\?/', $url) ? '&page=' : '?page=';
  echo '<div class="article_nav">';
  if ($index < $n - 1) {
    ?>
    <div class="alignleft">
      <a href="<?php echo $url . ($index+1); ?>">&larr; Older Articles</a>
    </div>
    <?php
  }
  if ($index > 0) {
    ?>
    <div class="alignright">
      <a href="<?php echo ($index > 1) ? $url . ($index-1) : substr($url, 0, -6); ?>">
        Newer Articles &rarr;
      </a>
    </div>
    <?php
  }
  echo '</div><br />';
}


############################## COMMON FUNCTIONS ################################


/*******************************************************
 * @function get_articles
 * @returns a list of articles in the folder ARTICLEDATA
 */
function get_articles() {
  $articles = array();
  $files = getFiles(ARTICLEDATA);
  foreach ($files as $file) {
    if (is_file(ARTICLEDATA . $file) && preg_match("/.xml$/", $file)) {
      $articles[] = $file;
    }
  }
  sort($articles);
  return array_reverse($articles);
}


?>
